<?php

/**
 * Base class extended from other class
 *
 *
 * @package opTask
 * @version $Id$
 * @license X-TRANS Develop License 1.0
 */

use Fuel\Core\Controller_Template;
use Fuel\Core\View;
use Fuel\Core\Lang;
use Fuel\Core\Asset;
use Auth\Auth;

class Controller_Base extends Controller_Template
{
    // Set template layout to use
    // public $template = 'layout/template';

    public $isRequireLogin = true;

    /**
     * Run before display a page
     *
     * @access public
     *
     */
    public function before()
    {
        parent::before();

        // load base css
        $this->baseCss();
        // load base css
        $this->baseJs();

        if (!$this->isRequireLogin) {
            return;
        }

        // check login
        $controller = strtolower(Request::active()->controller);
        $methodName = Request::active()->action;

        View::set_global('controller', $controller, false);
        View::set_global('method', $methodName, false);


        // Account must have rights to access page
        switch ($methodName) {
            case 'change_password' :
            case 'login' :
            case 'logout' :
            case 'error' :
            case '404' :
                return;
            default :
                // check rights to access page
                $this->checkRights($controller, $methodName);
                break;
        }

        Config::load('setting', 'setting_custom');
        $redeemPeriod = Config::get('setting_custom.redeemPeriod');

        $date = date('d');
        $isRedeemableMenu = $date >= $redeemPeriod['startDate'] && $date <= $redeemPeriod['endDate'];
        View::set_global('isRedeemableMenu', $isRedeemableMenu, false);
    }

    /**
     * check page permissions
     *
     * @param string $controllerName controller name
     * @param string $methodName method name
     * @return void
     *
     * @access public
     *
     */
    public function checkRights($controllerName,$methodName)
    {
        // check logged in?
        if (Auth::check()) {
             //check have rights to access page if logged in
            if (!Auth::has_access("{$controllerName}.{$methodName}")) {
                Response::redirect('base/error');
            }
        } else {
            Response::redirect('account/login');
        }
    }

    /**
     * display error 404 not page found
     *
     * @access public
     *
     */
    public function action_404()
    {
        return View::forge('error/404');
    }

    /**
     * display access denied page
     *
     * @access public
     *
     */
    public function action_error()
    {
        return View::forge('error/access_denied');
    }


    /**
     * load base css
     *
     * @access public
     *
     */
    public function baseCss()
    {
    }

    /**
     * load base js
     *
     * @access public
     *
     */
    public function baseJs()
    {
    }

    /**
     * add more neccessary css file to use
     *
     * @param string $file name of css file
     *
     * @access public
     *
     */
    public function addCss($file)
    {
        Asset::css($file, array(), 'css', false);
    }

    /**
     * add more neccessary js file to use
     *
     * @param string $file name of js file
     *
     * @access public
     *
     */
    public function addJs($file)
    {
        Asset::js($file, array(), 'js', false);
    }

}
