<?php
/**
 * /validation.php
 *

 *
 * @package optask
 * @since Sep 4, 2014
 * @version $Id$
 * @license X-TRANS Develop License 1.0
 */

/**
 * Validation
 *
 * <pre>
 * </pre>
 *

 *
 * @package optask
 * @version 1.0
 * @license X-TRANS Develop License 1.0
 */
class Validation extends Fuel\Core\Validation
{

    /**
     * Validate uniue user name
     *
     * @param string $val username
     * @return boolean
     *
     * @access public
     *
     */
    public static function _validation_username($val)
    {
        $account = Model_Account::find('first', array('where' => array('username' => $val)));

        if ($account)
        {
            Validation::active()->set_message('username', 'Account already exists');
            return false;
        }

        Validation::active()->set_message('username', 'Accept only letters and characters: -_. @');

        if (empty($val)) {
            return true;
        }
        return (boolean) preg_match('/^[\w\-\.\@]+$/', $val);
    }

    public static function _validation_confirm_password($confrim_password, $password) {
        Validation::active()->set_message('confirm_password', 'Confirmation password does not match');
        return $confrim_password === $password;
    }

    /**
     * validate unique field
     *
     * @param mix $val value need to validate
     * @param string $options table column to validate unique
     * @param object $obj object to validate
     *
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_unique($val, $options, $obj)
    {
        $result = $obj->find('first', array(
            'where' => array(
                array('id', '!=', $obj['id']),
                array($options => $val),
                array('deleted_status' => null)
            )
        ));
        Validation::active()->set_message('unique', __('validate.The field :label must be unique, but :value has already been used'));
        return (boolean) (count($result) == 0);
    }

    /**
     * validate unique position
     *
     * @param mix $val value need to validate
     * @param string $options table column to validate unique
     * @param object $obj object to validate
     *
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_uniqueposition($val, $options, $obj)
    {
        $result = $obj->find('first', array(
            'where' => array(
                array('id', '!=', $obj['id']),
                array($options => $val)
            )
        ));
        Validation::active()->set_message('uniqueposition', __('validate.The field :label must be unique, but :value has already been used'));
        return (boolean) (count($result) == 0);
    }

    /**
     * validate task datetime
     *
     * @param mix $val value need to validate
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_datetime($val)
    {
        Validation::active()->set_message('datetime', __('validate.The field :label is invalid datetime format'));
        return Validation::validateDate($val, 'Y/m/d H:i');
    }

    /**
     * validate task time
     *
     * @param mix $val value need to validate
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_time($val)
    {
        Validation::active()->set_message('time', __('validate.The field :label is invalid time format'));
        return Validation::validateDate($val, 'H:i');
    }

    /**
     * validate task date
     *
     * @param mix $val value need to validate
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_date($val)
    {
        Validation::active()->set_message('date', __('validate.The field :label is invalid date format'));
        return Validation::validateDate($val, 'Y/m/d');
    }

    /**
     * validate month
     *
     * @param mix $val value need to validate
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_month($val)
    {
        Validation::active()->set_message('date', __('validate.The field :label is invalid date format'));
        return Validation::validateDate($val, 'Y/m');
    }

    /**
     * validate number
     *
     * @param mix $val value need to validate
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_number($val)
    {
        if($val == ''){
            return true;
        }
        Validation::active()->set_message('number', __('validate.The field :label is not a valid number'));
        return (boolean) preg_match('/^([1-9][0-9]*)$/', $val);
    }

    /**
     * validate start time < end time
     *
     * @param string $val value need to validate
     * @param string $end end time
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_starttime($val, $end)
    {
        $result = $val < $end;
        Validation::active()->set_message('starttime', __('validate.Start time must be less than end time'));
        return (boolean) $result;
    }

    /**
     * validate end time > start time
     *
     * @param string $val value need to validate
     * @param string $end end time
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_endtime($val, $start)
    {
        $result = $val > $start;
        Validation::active()->set_message('endtime', __('validate.End time must be greater than start time'));
        return (boolean) $result;
    }

    /**
     * validate task datetime
     *
     * @param string $date value need to validate
     * @param string $format format datetime to validate
     * @return boolean result of validation
     *
     * @access protected
     * @since 1.0
     * @version 1.0
     *
     */
    protected static function validateDate($date, $format = 'Y/m/d H:i')
    {
        $d = DateTime::createFromFormat($format, $date);
        return $d && $d->format($format) == $date;
    }

    /**
     * validate a natural non-zero number
     *
     * @param mix $str value need to validate
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_natural_no_zero_number($str)
    {
        Validation::active()->set_message('natural_no_zero_number', __('validate.The field :label is not a non-zero positive natural number'));
        return ($str != 0 && preg_match('/^[0-9]+$/', $str));
    }

    /**
     * validate specified date <= current date
     *
     * @param string $val specified date need to be validated
     * @param string $current_date current date
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public static function _validation_pastdate($val, $current_date)
    {
        $result = (strtotime($val) <= strtotime($current_date));
        Validation::active()->set_message('pastdate', __('validate.The field :label is must be a past or current date'));
        return (boolean) $result;
    }

    public static function _validation_checkdate($end_date, $start_date)
    {
        $result = (strtotime($start_date) <= strtotime($end_date));
        Validation::active()->set_message('checkdate', 'Invalid date');
        return (boolean) $result;
    }

    /**
     * validate require
     *
     * @param string $val value to validate
     * @return boolean result of validation
     *
     * @access public
     * @since 1.0
     * @version 1.0
     *
     */
    public function _validation_required($val){
        if(is_string($val)){
            $val = trim($val);
        }
        return !($val === false or $val === null or $val === '' or $val === array());
    }

    public static function _validation_is_number($str)
    {
        Validation::active()->set_message('is_number', 'Input number only');
        return is_numeric($str);
    }

}
