<?php
/**
 * /task.php
 *
 
 * 
 * @package optask
 * @since Sep 18, 2014
 * @version $Id$
 * @license X-TRANS Develop License 1.0
 */

/**
 * Test Task model
 *
 * <pre>
 * </pre>
 *
 
 * 
 * @package optask
 * @version 1.0
 * @license X-TRANS Develop License 1.0
 */
class Test_Model_Task extends TestCase
{
    /**
     * Test validate
     *
     * @return void
     *
     * @access public
     * @since 1.0
     * @version 1.0
     * 
     */
    public function testValidate()
    {
        //test case 1
        $testcase1 = array();
        $val = Model_Task::validate('create', $testcase1);
        $val->run($testcase1);
        $err = $val->error_message();
        $this->assertNotEmpty($err['name']);
        $this->assertNotEmpty($err['start_time']);
        $this->assertNotEmpty($err['end_time']);
        $this->assertNotEmpty($err['classification_id']);
        $this->assertNotEmpty($err['color_id']);
        $this->assertNotEmpty($err['position']);

        //test case 2
        $testcase2 = array(
            'name' => 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa',
            'start_time' => 'aaa',
            'end_time' => 'bbb',
            'ticket_number' => '0',
            'classification_id' => 'test',
            'color_id' => 'test'
        );
        $val->run($testcase2);
        $err = $val->error_message();
        $this->assertNotEmpty($err['name']);
        $this->assertNotEmpty($err['start_time']);
        $this->assertNotEmpty($err['end_time']);
        $this->assertNotEmpty($err['ticket_number']);
        $this->assertNotEmpty($err['classification_id']);
        $this->assertNotEmpty($err['color_id']);
    }

    /**
     * prepare data for task view
     *
     * @return void
     *
     * @access public
     * @since 1.0
     * @version 1.0
     * 
     */
    public function prepareDataForTaskView()
    {
        DB::query('delete from task')->execute();
        DB::query('delete from classification')->execute();
        DB::query('delete from status')->execute();
        DB::query('delete from position')->execute();

        // prepare color
        DB::query("INSERT INTO color (id, name, rgb) VALUES
                    (1, 'なし','FFFFFF');")->execute();
        // prepare classifiction
        DB::query("INSERT INTO classification (id, name) VALUES
                    (1, '通常');")->execute();
        // prepare task
        DB::query("INSERT INTO task (id, name, start_time,end_time,ticket_number,comment,classification_id,color_id,type,update_time) VALUES
                    (1, 'task1','2014-09-24 08:42:00','2014-09-25 08:42:00','123','comment',1,1,1,'2014-09-29 10:00:00'),
                    (2, 'task2','2014-09-27 08:42:00','2014-09-29 08:42:00','123','comment',1,1,1,'2014-09-29 10:00:00');")
                ->execute();

        // prepare position
        DB::query("INSERT INTO  `position`(`id`, `name`, `order`) VALUES
                    (1, 'AM',1);")->execute();
        // prepare status
        DB::query("INSERT INTO `status`(`id`, `task_id`, `position_id`, `status`)  VALUES
                    (1, 2, 1, 1);")->execute();
    }

    /**
     * Test method getTasksByMonth()
     *
     * @return void
     *
     * @access public
     * @since 1.0
     * @version 1.0
     * 
     */
    public function testGetTasksByMonth()
    {
        // prepare data
        $this->prepareDataForTaskView();

        $tasks = Model_Task::getTasksByMonth('2014/09');

        $actual = array();
        foreach($tasks as $key=> $val) {
            $actual[$key]['id'] = $val['id'];
            $actual[$key]['name'] = $val['name'];
            $actual[$key]['start_time'] = $val['start_time'];
            $actual[$key]['end_time'] = $val['end_time'];
            $actual[$key]['ticket_number'] = $val['ticket_number'];
            $actual[$key]['comment'] = $val['comment'];
            $actual[$key]['classification_id'] = $val['classification_id'];
            $actual[$key]['color_id'] = $val['color_id'];
            $actual[$key]['type'] = $val['type'];
            $actual[$key]['def_id'] = $val['def_id'];
            $actual[$key]['update_time'] = $val['update_time'];
            $actual[$key]['deleted_status'] = $val['deleted_status'];
            $actual[$key]['rgb'] = $val['rgb'];
            $actual[$key]['class_name'] = $val['class_name'];

        }
        $expected = array(
            '1' => array(
                'id' => '1',
                'name' => 'task1',
                'start_time' => '2014-09-24 08:42:00',
                'end_time' => '2014-09-25 08:42:00',
                'ticket_number' => '123',
                'comment' => 'comment',
                'classification_id' => '1',
                'color_id' => '1',
                'type' => '1',
                'def_id' => '',
                'update_time' => '2014-09-29 10:00:00',
                'deleted_status' => '0',
                'rgb'=>'FFFFFF',
                'class_name'=> '通常'
            ),
            '2' => array(
                'id' => 2,
                'name' => 'task2',
                'start_time' => '2014-09-27 08:42:00',
                'end_time' => '2014-09-29 08:42:00',
                'ticket_number' => '123',
                'comment' => 'comment',
                'classification_id' => '1',
                'color_id' => '1',
                'type' => '1',
                'def_id' => '',
                'update_time' => '2014-09-29 10:00:00',
                'deleted_status' => '0',
                'rgb'=>'FFFFFF',
                'class_name'=> '通常'
            ),


        );

        $this->assertEquals($actual,$expected);
    }

    /**
     * Test method getTaskByDay()
     *
     * @return void
     *
     * @access public
     * @since 1.0
     * @version 1.0
     * 
     */
    public function testGetTaskByDay()
    {
        // prepare data for day view
        $this->prepareDataForTaskView();

        $tasks = Model_Task::getTaskByDay('2014/09/27');

        $actual = array();
        foreach($tasks as $key=> $val) {
            $actual[$key]['id'] = $val['id'];
            $actual[$key]['name'] = $val['name'];
            $actual[$key]['start_time'] = $val['start_time'];
            $actual[$key]['end_time'] = $val['end_time'];
            $actual[$key]['ticket_number'] = $val['ticket_number'];
            $actual[$key]['comment'] = $val['comment'];
            $actual[$key]['classification_id'] = $val['classification_id'];
            $actual[$key]['color_id'] = $val['color_id'];
            $actual[$key]['type'] = $val['type'];
            $actual[$key]['def_id'] = $val['def_id'];
            $actual[$key]['update_time'] = $val['update_time'];
            $actual[$key]['deleted_status'] = $val['deleted_status'];
            $actual[$key]['rgb'] = $val['rgb'];
            $actual[$key]['class_name'] = $val['class_name'];
            foreach($val['status'] as $k => $v) {
                $actual[$key]['status'] = $v['position_id'];
            }
        }


        $expected = array(
            '2' => array(
                'id' => '2',
                'name' => 'task2',
                'start_time' => '2014-09-27 08:42:00',
                'end_time' => '2014-09-29 08:42:00',
                'ticket_number' => '123',
                'comment' => 'comment',
                'classification_id' => '1',
                'color_id' => '1',
                'type' => '1',
                'def_id' => null,
                'update_time' => '2014-09-29 10:00:00',
                'deleted_status' => '0',
                'rgb'=>'FFFFFF',
                'class_name'=> '通常',
                'status' => '1'
            )
        );
        $this->assertEquals($actual,$expected);
    }

    /**
     * Test method getTaskByShift()
     *
     * @return void
     *
     * @access public
     * @since 1.0
     * @version 1.0
     * 
     */
    public function testGetTaskByShift()
    {
        // prepare data to test view task
        $this->prepareDataForTaskView();
        $shift = 1; // 07:30 -> 15:00

        $tasks = Model_Task::getTaskByShift('2014/09/27', $shift);

        $actual = array();
        foreach($tasks as $key=> $val) {
            $actual[$key]['id'] = $val['id'];
            $actual[$key]['name'] = $val['name'];
            $actual[$key]['start_time'] = $val['start_time'];
            $actual[$key]['end_time'] = $val['end_time'];
            $actual[$key]['ticket_number'] = $val['ticket_number'];
            $actual[$key]['comment'] = $val['comment'];
            $actual[$key]['classification_id'] = $val['classification_id'];
            $actual[$key]['color_id'] = $val['color_id'];
            $actual[$key]['type'] = $val['type'];
            $actual[$key]['def_id'] = $val['def_id'];
            $actual[$key]['update_time'] = $val['update_time'];
            $actual[$key]['deleted_status'] = $val['deleted_status'];
            $actual[$key]['rgb'] = 'FFFFFF';
            $actual[$key]['class_name'] = $val['class_name'];
            foreach($val['status'] as $k => $v) {
                $actual[$key]['status'] = $v['position_id'];
            }
        }

        $expected = array(
            '2' => array(
                'id' => '2',
                'name' => 'task2',
                'start_time' => '2014-09-27 08:42:00',
                'end_time' => '2014-09-29 08:42:00',
                'ticket_number' => '123',
                'comment' => 'comment',
                'classification_id' => '1',
                'color_id' => '1',
                'type' => '1',
                'def_id' => null,
                'update_time' => '2014-09-29 10:00:00',
                'deleted_status' => '0',
                'rgb'=>'FFFFFF',
                'class_name'=> '通常',
                'status' => '1'
            )
        );

        $this->assertEquals($actual,$expected);
    }
}

